# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PasswordPolicyArgs', 'PasswordPolicy']

@pulumi.input_type
class PasswordPolicyArgs:
    def __init__(__self__, *,
                 hard_expiry: Optional[pulumi.Input[builtins.bool]] = None,
                 max_login_attemps: Optional[pulumi.Input[builtins.int]] = None,
                 max_password_age: Optional[pulumi.Input[builtins.int]] = None,
                 minimum_password_different_character: Optional[pulumi.Input[builtins.int]] = None,
                 minimum_password_length: Optional[pulumi.Input[builtins.int]] = None,
                 password_not_contain_user_name: Optional[pulumi.Input[builtins.bool]] = None,
                 password_reuse_prevention: Optional[pulumi.Input[builtins.int]] = None,
                 require_lowercase_characters: Optional[pulumi.Input[builtins.bool]] = None,
                 require_numbers: Optional[pulumi.Input[builtins.bool]] = None,
                 require_symbols: Optional[pulumi.Input[builtins.bool]] = None,
                 require_uppercase_characters: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a PasswordPolicy resource.
        :param pulumi.Input[builtins.bool] hard_expiry: Whether to restrict logon after the password expires. Value:
               - true: After the password expires, you cannot log in to the console. You must reset the password of the RAM user through the main account or a RAM user with administrator permissions to log on normally.
               - false (default): After the password expires, the RAM user can change the password and log on normally.
        :param pulumi.Input[builtins.int] max_login_attemps: Password retry constraint. After entering the wrong password continuously for the set number of times, the account will be locked for one hour.
               Value range: 0~32.
               Default value: 0, which means that the password retry constraint is not enabled.
        :param pulumi.Input[builtins.int] max_password_age: Password validity period.
               Value range: 0~1095. Unit: days.
               Default value: 0, which means never expires.
        :param pulumi.Input[builtins.int] minimum_password_different_character: The minimum number of unique characters in the password.
               Valid values: 0 to 8.
               The default value is 0, which indicates that no limits are imposed on the number of unique characters in a password.
        :param pulumi.Input[builtins.int] minimum_password_length: The minimum number of characters in the password.
               Valid values: 8 to 32. Default value: 8.
        :param pulumi.Input[builtins.bool] password_not_contain_user_name: Whether the user name is not allowed in the password. Value:
               - true: The password cannot contain the user name.
               - false (default): The user name can be included in the password.
        :param pulumi.Input[builtins.int] password_reuse_prevention: Historical password check policy.
               Do not use the previous N Passwords. The value range of N is 0 to 24.
               Default value: 0, indicating that the historical password check policy is not enabled.
        :param pulumi.Input[builtins.bool] require_lowercase_characters: Specifies whether the password must contain lowercase letters. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_numbers: Specifies whether the password must contain digits. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_symbols: Specifies whether the password must contain special characters. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_uppercase_characters: Specifies whether the password must contain uppercase letters. Valid values:
               - true
               - false (default)
        """
        if hard_expiry is not None:
            pulumi.set(__self__, "hard_expiry", hard_expiry)
        if max_login_attemps is not None:
            pulumi.set(__self__, "max_login_attemps", max_login_attemps)
        if max_password_age is not None:
            pulumi.set(__self__, "max_password_age", max_password_age)
        if minimum_password_different_character is not None:
            pulumi.set(__self__, "minimum_password_different_character", minimum_password_different_character)
        if minimum_password_length is not None:
            pulumi.set(__self__, "minimum_password_length", minimum_password_length)
        if password_not_contain_user_name is not None:
            pulumi.set(__self__, "password_not_contain_user_name", password_not_contain_user_name)
        if password_reuse_prevention is not None:
            pulumi.set(__self__, "password_reuse_prevention", password_reuse_prevention)
        if require_lowercase_characters is not None:
            pulumi.set(__self__, "require_lowercase_characters", require_lowercase_characters)
        if require_numbers is not None:
            pulumi.set(__self__, "require_numbers", require_numbers)
        if require_symbols is not None:
            pulumi.set(__self__, "require_symbols", require_symbols)
        if require_uppercase_characters is not None:
            pulumi.set(__self__, "require_uppercase_characters", require_uppercase_characters)

    @property
    @pulumi.getter(name="hardExpiry")
    def hard_expiry(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to restrict logon after the password expires. Value:
        - true: After the password expires, you cannot log in to the console. You must reset the password of the RAM user through the main account or a RAM user with administrator permissions to log on normally.
        - false (default): After the password expires, the RAM user can change the password and log on normally.
        """
        return pulumi.get(self, "hard_expiry")

    @hard_expiry.setter
    def hard_expiry(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hard_expiry", value)

    @property
    @pulumi.getter(name="maxLoginAttemps")
    def max_login_attemps(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Password retry constraint. After entering the wrong password continuously for the set number of times, the account will be locked for one hour.
        Value range: 0~32.
        Default value: 0, which means that the password retry constraint is not enabled.
        """
        return pulumi.get(self, "max_login_attemps")

    @max_login_attemps.setter
    def max_login_attemps(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_login_attemps", value)

    @property
    @pulumi.getter(name="maxPasswordAge")
    def max_password_age(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Password validity period.
        Value range: 0~1095. Unit: days.
        Default value: 0, which means never expires.
        """
        return pulumi.get(self, "max_password_age")

    @max_password_age.setter
    def max_password_age(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_password_age", value)

    @property
    @pulumi.getter(name="minimumPasswordDifferentCharacter")
    def minimum_password_different_character(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The minimum number of unique characters in the password.
        Valid values: 0 to 8.
        The default value is 0, which indicates that no limits are imposed on the number of unique characters in a password.
        """
        return pulumi.get(self, "minimum_password_different_character")

    @minimum_password_different_character.setter
    def minimum_password_different_character(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "minimum_password_different_character", value)

    @property
    @pulumi.getter(name="minimumPasswordLength")
    def minimum_password_length(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The minimum number of characters in the password.
        Valid values: 8 to 32. Default value: 8.
        """
        return pulumi.get(self, "minimum_password_length")

    @minimum_password_length.setter
    def minimum_password_length(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "minimum_password_length", value)

    @property
    @pulumi.getter(name="passwordNotContainUserName")
    def password_not_contain_user_name(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the user name is not allowed in the password. Value:
        - true: The password cannot contain the user name.
        - false (default): The user name can be included in the password.
        """
        return pulumi.get(self, "password_not_contain_user_name")

    @password_not_contain_user_name.setter
    def password_not_contain_user_name(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "password_not_contain_user_name", value)

    @property
    @pulumi.getter(name="passwordReusePrevention")
    def password_reuse_prevention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Historical password check policy.
        Do not use the previous N Passwords. The value range of N is 0 to 24.
        Default value: 0, indicating that the historical password check policy is not enabled.
        """
        return pulumi.get(self, "password_reuse_prevention")

    @password_reuse_prevention.setter
    def password_reuse_prevention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "password_reuse_prevention", value)

    @property
    @pulumi.getter(name="requireLowercaseCharacters")
    def require_lowercase_characters(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the password must contain lowercase letters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_lowercase_characters")

    @require_lowercase_characters.setter
    def require_lowercase_characters(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_lowercase_characters", value)

    @property
    @pulumi.getter(name="requireNumbers")
    def require_numbers(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the password must contain digits. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_numbers")

    @require_numbers.setter
    def require_numbers(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_numbers", value)

    @property
    @pulumi.getter(name="requireSymbols")
    def require_symbols(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the password must contain special characters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_symbols")

    @require_symbols.setter
    def require_symbols(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_symbols", value)

    @property
    @pulumi.getter(name="requireUppercaseCharacters")
    def require_uppercase_characters(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the password must contain uppercase letters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_uppercase_characters")

    @require_uppercase_characters.setter
    def require_uppercase_characters(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_uppercase_characters", value)


@pulumi.input_type
class _PasswordPolicyState:
    def __init__(__self__, *,
                 hard_expiry: Optional[pulumi.Input[builtins.bool]] = None,
                 max_login_attemps: Optional[pulumi.Input[builtins.int]] = None,
                 max_password_age: Optional[pulumi.Input[builtins.int]] = None,
                 minimum_password_different_character: Optional[pulumi.Input[builtins.int]] = None,
                 minimum_password_length: Optional[pulumi.Input[builtins.int]] = None,
                 password_not_contain_user_name: Optional[pulumi.Input[builtins.bool]] = None,
                 password_reuse_prevention: Optional[pulumi.Input[builtins.int]] = None,
                 require_lowercase_characters: Optional[pulumi.Input[builtins.bool]] = None,
                 require_numbers: Optional[pulumi.Input[builtins.bool]] = None,
                 require_symbols: Optional[pulumi.Input[builtins.bool]] = None,
                 require_uppercase_characters: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering PasswordPolicy resources.
        :param pulumi.Input[builtins.bool] hard_expiry: Whether to restrict logon after the password expires. Value:
               - true: After the password expires, you cannot log in to the console. You must reset the password of the RAM user through the main account or a RAM user with administrator permissions to log on normally.
               - false (default): After the password expires, the RAM user can change the password and log on normally.
        :param pulumi.Input[builtins.int] max_login_attemps: Password retry constraint. After entering the wrong password continuously for the set number of times, the account will be locked for one hour.
               Value range: 0~32.
               Default value: 0, which means that the password retry constraint is not enabled.
        :param pulumi.Input[builtins.int] max_password_age: Password validity period.
               Value range: 0~1095. Unit: days.
               Default value: 0, which means never expires.
        :param pulumi.Input[builtins.int] minimum_password_different_character: The minimum number of unique characters in the password.
               Valid values: 0 to 8.
               The default value is 0, which indicates that no limits are imposed on the number of unique characters in a password.
        :param pulumi.Input[builtins.int] minimum_password_length: The minimum number of characters in the password.
               Valid values: 8 to 32. Default value: 8.
        :param pulumi.Input[builtins.bool] password_not_contain_user_name: Whether the user name is not allowed in the password. Value:
               - true: The password cannot contain the user name.
               - false (default): The user name can be included in the password.
        :param pulumi.Input[builtins.int] password_reuse_prevention: Historical password check policy.
               Do not use the previous N Passwords. The value range of N is 0 to 24.
               Default value: 0, indicating that the historical password check policy is not enabled.
        :param pulumi.Input[builtins.bool] require_lowercase_characters: Specifies whether the password must contain lowercase letters. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_numbers: Specifies whether the password must contain digits. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_symbols: Specifies whether the password must contain special characters. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_uppercase_characters: Specifies whether the password must contain uppercase letters. Valid values:
               - true
               - false (default)
        """
        if hard_expiry is not None:
            pulumi.set(__self__, "hard_expiry", hard_expiry)
        if max_login_attemps is not None:
            pulumi.set(__self__, "max_login_attemps", max_login_attemps)
        if max_password_age is not None:
            pulumi.set(__self__, "max_password_age", max_password_age)
        if minimum_password_different_character is not None:
            pulumi.set(__self__, "minimum_password_different_character", minimum_password_different_character)
        if minimum_password_length is not None:
            pulumi.set(__self__, "minimum_password_length", minimum_password_length)
        if password_not_contain_user_name is not None:
            pulumi.set(__self__, "password_not_contain_user_name", password_not_contain_user_name)
        if password_reuse_prevention is not None:
            pulumi.set(__self__, "password_reuse_prevention", password_reuse_prevention)
        if require_lowercase_characters is not None:
            pulumi.set(__self__, "require_lowercase_characters", require_lowercase_characters)
        if require_numbers is not None:
            pulumi.set(__self__, "require_numbers", require_numbers)
        if require_symbols is not None:
            pulumi.set(__self__, "require_symbols", require_symbols)
        if require_uppercase_characters is not None:
            pulumi.set(__self__, "require_uppercase_characters", require_uppercase_characters)

    @property
    @pulumi.getter(name="hardExpiry")
    def hard_expiry(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to restrict logon after the password expires. Value:
        - true: After the password expires, you cannot log in to the console. You must reset the password of the RAM user through the main account or a RAM user with administrator permissions to log on normally.
        - false (default): After the password expires, the RAM user can change the password and log on normally.
        """
        return pulumi.get(self, "hard_expiry")

    @hard_expiry.setter
    def hard_expiry(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hard_expiry", value)

    @property
    @pulumi.getter(name="maxLoginAttemps")
    def max_login_attemps(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Password retry constraint. After entering the wrong password continuously for the set number of times, the account will be locked for one hour.
        Value range: 0~32.
        Default value: 0, which means that the password retry constraint is not enabled.
        """
        return pulumi.get(self, "max_login_attemps")

    @max_login_attemps.setter
    def max_login_attemps(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_login_attemps", value)

    @property
    @pulumi.getter(name="maxPasswordAge")
    def max_password_age(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Password validity period.
        Value range: 0~1095. Unit: days.
        Default value: 0, which means never expires.
        """
        return pulumi.get(self, "max_password_age")

    @max_password_age.setter
    def max_password_age(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_password_age", value)

    @property
    @pulumi.getter(name="minimumPasswordDifferentCharacter")
    def minimum_password_different_character(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The minimum number of unique characters in the password.
        Valid values: 0 to 8.
        The default value is 0, which indicates that no limits are imposed on the number of unique characters in a password.
        """
        return pulumi.get(self, "minimum_password_different_character")

    @minimum_password_different_character.setter
    def minimum_password_different_character(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "minimum_password_different_character", value)

    @property
    @pulumi.getter(name="minimumPasswordLength")
    def minimum_password_length(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The minimum number of characters in the password.
        Valid values: 8 to 32. Default value: 8.
        """
        return pulumi.get(self, "minimum_password_length")

    @minimum_password_length.setter
    def minimum_password_length(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "minimum_password_length", value)

    @property
    @pulumi.getter(name="passwordNotContainUserName")
    def password_not_contain_user_name(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the user name is not allowed in the password. Value:
        - true: The password cannot contain the user name.
        - false (default): The user name can be included in the password.
        """
        return pulumi.get(self, "password_not_contain_user_name")

    @password_not_contain_user_name.setter
    def password_not_contain_user_name(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "password_not_contain_user_name", value)

    @property
    @pulumi.getter(name="passwordReusePrevention")
    def password_reuse_prevention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Historical password check policy.
        Do not use the previous N Passwords. The value range of N is 0 to 24.
        Default value: 0, indicating that the historical password check policy is not enabled.
        """
        return pulumi.get(self, "password_reuse_prevention")

    @password_reuse_prevention.setter
    def password_reuse_prevention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "password_reuse_prevention", value)

    @property
    @pulumi.getter(name="requireLowercaseCharacters")
    def require_lowercase_characters(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the password must contain lowercase letters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_lowercase_characters")

    @require_lowercase_characters.setter
    def require_lowercase_characters(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_lowercase_characters", value)

    @property
    @pulumi.getter(name="requireNumbers")
    def require_numbers(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the password must contain digits. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_numbers")

    @require_numbers.setter
    def require_numbers(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_numbers", value)

    @property
    @pulumi.getter(name="requireSymbols")
    def require_symbols(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the password must contain special characters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_symbols")

    @require_symbols.setter
    def require_symbols(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_symbols", value)

    @property
    @pulumi.getter(name="requireUppercaseCharacters")
    def require_uppercase_characters(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the password must contain uppercase letters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_uppercase_characters")

    @require_uppercase_characters.setter
    def require_uppercase_characters(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_uppercase_characters", value)


@pulumi.type_token("alicloud:ram/passwordPolicy:PasswordPolicy")
class PasswordPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 hard_expiry: Optional[pulumi.Input[builtins.bool]] = None,
                 max_login_attemps: Optional[pulumi.Input[builtins.int]] = None,
                 max_password_age: Optional[pulumi.Input[builtins.int]] = None,
                 minimum_password_different_character: Optional[pulumi.Input[builtins.int]] = None,
                 minimum_password_length: Optional[pulumi.Input[builtins.int]] = None,
                 password_not_contain_user_name: Optional[pulumi.Input[builtins.bool]] = None,
                 password_reuse_prevention: Optional[pulumi.Input[builtins.int]] = None,
                 require_lowercase_characters: Optional[pulumi.Input[builtins.bool]] = None,
                 require_numbers: Optional[pulumi.Input[builtins.bool]] = None,
                 require_symbols: Optional[pulumi.Input[builtins.bool]] = None,
                 require_uppercase_characters: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        ## Import

        RAM Password Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ram/passwordPolicy:PasswordPolicy example <id>.
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] hard_expiry: Whether to restrict logon after the password expires. Value:
               - true: After the password expires, you cannot log in to the console. You must reset the password of the RAM user through the main account or a RAM user with administrator permissions to log on normally.
               - false (default): After the password expires, the RAM user can change the password and log on normally.
        :param pulumi.Input[builtins.int] max_login_attemps: Password retry constraint. After entering the wrong password continuously for the set number of times, the account will be locked for one hour.
               Value range: 0~32.
               Default value: 0, which means that the password retry constraint is not enabled.
        :param pulumi.Input[builtins.int] max_password_age: Password validity period.
               Value range: 0~1095. Unit: days.
               Default value: 0, which means never expires.
        :param pulumi.Input[builtins.int] minimum_password_different_character: The minimum number of unique characters in the password.
               Valid values: 0 to 8.
               The default value is 0, which indicates that no limits are imposed on the number of unique characters in a password.
        :param pulumi.Input[builtins.int] minimum_password_length: The minimum number of characters in the password.
               Valid values: 8 to 32. Default value: 8.
        :param pulumi.Input[builtins.bool] password_not_contain_user_name: Whether the user name is not allowed in the password. Value:
               - true: The password cannot contain the user name.
               - false (default): The user name can be included in the password.
        :param pulumi.Input[builtins.int] password_reuse_prevention: Historical password check policy.
               Do not use the previous N Passwords. The value range of N is 0 to 24.
               Default value: 0, indicating that the historical password check policy is not enabled.
        :param pulumi.Input[builtins.bool] require_lowercase_characters: Specifies whether the password must contain lowercase letters. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_numbers: Specifies whether the password must contain digits. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_symbols: Specifies whether the password must contain special characters. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_uppercase_characters: Specifies whether the password must contain uppercase letters. Valid values:
               - true
               - false (default)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[PasswordPolicyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        RAM Password Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ram/passwordPolicy:PasswordPolicy example <id>.
        ```

        :param str resource_name: The name of the resource.
        :param PasswordPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PasswordPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 hard_expiry: Optional[pulumi.Input[builtins.bool]] = None,
                 max_login_attemps: Optional[pulumi.Input[builtins.int]] = None,
                 max_password_age: Optional[pulumi.Input[builtins.int]] = None,
                 minimum_password_different_character: Optional[pulumi.Input[builtins.int]] = None,
                 minimum_password_length: Optional[pulumi.Input[builtins.int]] = None,
                 password_not_contain_user_name: Optional[pulumi.Input[builtins.bool]] = None,
                 password_reuse_prevention: Optional[pulumi.Input[builtins.int]] = None,
                 require_lowercase_characters: Optional[pulumi.Input[builtins.bool]] = None,
                 require_numbers: Optional[pulumi.Input[builtins.bool]] = None,
                 require_symbols: Optional[pulumi.Input[builtins.bool]] = None,
                 require_uppercase_characters: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PasswordPolicyArgs.__new__(PasswordPolicyArgs)

            __props__.__dict__["hard_expiry"] = hard_expiry
            __props__.__dict__["max_login_attemps"] = max_login_attemps
            __props__.__dict__["max_password_age"] = max_password_age
            __props__.__dict__["minimum_password_different_character"] = minimum_password_different_character
            __props__.__dict__["minimum_password_length"] = minimum_password_length
            __props__.__dict__["password_not_contain_user_name"] = password_not_contain_user_name
            __props__.__dict__["password_reuse_prevention"] = password_reuse_prevention
            __props__.__dict__["require_lowercase_characters"] = require_lowercase_characters
            __props__.__dict__["require_numbers"] = require_numbers
            __props__.__dict__["require_symbols"] = require_symbols
            __props__.__dict__["require_uppercase_characters"] = require_uppercase_characters
        super(PasswordPolicy, __self__).__init__(
            'alicloud:ram/passwordPolicy:PasswordPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            hard_expiry: Optional[pulumi.Input[builtins.bool]] = None,
            max_login_attemps: Optional[pulumi.Input[builtins.int]] = None,
            max_password_age: Optional[pulumi.Input[builtins.int]] = None,
            minimum_password_different_character: Optional[pulumi.Input[builtins.int]] = None,
            minimum_password_length: Optional[pulumi.Input[builtins.int]] = None,
            password_not_contain_user_name: Optional[pulumi.Input[builtins.bool]] = None,
            password_reuse_prevention: Optional[pulumi.Input[builtins.int]] = None,
            require_lowercase_characters: Optional[pulumi.Input[builtins.bool]] = None,
            require_numbers: Optional[pulumi.Input[builtins.bool]] = None,
            require_symbols: Optional[pulumi.Input[builtins.bool]] = None,
            require_uppercase_characters: Optional[pulumi.Input[builtins.bool]] = None) -> 'PasswordPolicy':
        """
        Get an existing PasswordPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] hard_expiry: Whether to restrict logon after the password expires. Value:
               - true: After the password expires, you cannot log in to the console. You must reset the password of the RAM user through the main account or a RAM user with administrator permissions to log on normally.
               - false (default): After the password expires, the RAM user can change the password and log on normally.
        :param pulumi.Input[builtins.int] max_login_attemps: Password retry constraint. After entering the wrong password continuously for the set number of times, the account will be locked for one hour.
               Value range: 0~32.
               Default value: 0, which means that the password retry constraint is not enabled.
        :param pulumi.Input[builtins.int] max_password_age: Password validity period.
               Value range: 0~1095. Unit: days.
               Default value: 0, which means never expires.
        :param pulumi.Input[builtins.int] minimum_password_different_character: The minimum number of unique characters in the password.
               Valid values: 0 to 8.
               The default value is 0, which indicates that no limits are imposed on the number of unique characters in a password.
        :param pulumi.Input[builtins.int] minimum_password_length: The minimum number of characters in the password.
               Valid values: 8 to 32. Default value: 8.
        :param pulumi.Input[builtins.bool] password_not_contain_user_name: Whether the user name is not allowed in the password. Value:
               - true: The password cannot contain the user name.
               - false (default): The user name can be included in the password.
        :param pulumi.Input[builtins.int] password_reuse_prevention: Historical password check policy.
               Do not use the previous N Passwords. The value range of N is 0 to 24.
               Default value: 0, indicating that the historical password check policy is not enabled.
        :param pulumi.Input[builtins.bool] require_lowercase_characters: Specifies whether the password must contain lowercase letters. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_numbers: Specifies whether the password must contain digits. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_symbols: Specifies whether the password must contain special characters. Valid values:
               - true
               - false (default)
        :param pulumi.Input[builtins.bool] require_uppercase_characters: Specifies whether the password must contain uppercase letters. Valid values:
               - true
               - false (default)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PasswordPolicyState.__new__(_PasswordPolicyState)

        __props__.__dict__["hard_expiry"] = hard_expiry
        __props__.__dict__["max_login_attemps"] = max_login_attemps
        __props__.__dict__["max_password_age"] = max_password_age
        __props__.__dict__["minimum_password_different_character"] = minimum_password_different_character
        __props__.__dict__["minimum_password_length"] = minimum_password_length
        __props__.__dict__["password_not_contain_user_name"] = password_not_contain_user_name
        __props__.__dict__["password_reuse_prevention"] = password_reuse_prevention
        __props__.__dict__["require_lowercase_characters"] = require_lowercase_characters
        __props__.__dict__["require_numbers"] = require_numbers
        __props__.__dict__["require_symbols"] = require_symbols
        __props__.__dict__["require_uppercase_characters"] = require_uppercase_characters
        return PasswordPolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="hardExpiry")
    def hard_expiry(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to restrict logon after the password expires. Value:
        - true: After the password expires, you cannot log in to the console. You must reset the password of the RAM user through the main account or a RAM user with administrator permissions to log on normally.
        - false (default): After the password expires, the RAM user can change the password and log on normally.
        """
        return pulumi.get(self, "hard_expiry")

    @property
    @pulumi.getter(name="maxLoginAttemps")
    def max_login_attemps(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Password retry constraint. After entering the wrong password continuously for the set number of times, the account will be locked for one hour.
        Value range: 0~32.
        Default value: 0, which means that the password retry constraint is not enabled.
        """
        return pulumi.get(self, "max_login_attemps")

    @property
    @pulumi.getter(name="maxPasswordAge")
    def max_password_age(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Password validity period.
        Value range: 0~1095. Unit: days.
        Default value: 0, which means never expires.
        """
        return pulumi.get(self, "max_password_age")

    @property
    @pulumi.getter(name="minimumPasswordDifferentCharacter")
    def minimum_password_different_character(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The minimum number of unique characters in the password.
        Valid values: 0 to 8.
        The default value is 0, which indicates that no limits are imposed on the number of unique characters in a password.
        """
        return pulumi.get(self, "minimum_password_different_character")

    @property
    @pulumi.getter(name="minimumPasswordLength")
    def minimum_password_length(self) -> pulumi.Output[builtins.int]:
        """
        The minimum number of characters in the password.
        Valid values: 8 to 32. Default value: 8.
        """
        return pulumi.get(self, "minimum_password_length")

    @property
    @pulumi.getter(name="passwordNotContainUserName")
    def password_not_contain_user_name(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether the user name is not allowed in the password. Value:
        - true: The password cannot contain the user name.
        - false (default): The user name can be included in the password.
        """
        return pulumi.get(self, "password_not_contain_user_name")

    @property
    @pulumi.getter(name="passwordReusePrevention")
    def password_reuse_prevention(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Historical password check policy.
        Do not use the previous N Passwords. The value range of N is 0 to 24.
        Default value: 0, indicating that the historical password check policy is not enabled.
        """
        return pulumi.get(self, "password_reuse_prevention")

    @property
    @pulumi.getter(name="requireLowercaseCharacters")
    def require_lowercase_characters(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether the password must contain lowercase letters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_lowercase_characters")

    @property
    @pulumi.getter(name="requireNumbers")
    def require_numbers(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether the password must contain digits. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_numbers")

    @property
    @pulumi.getter(name="requireSymbols")
    def require_symbols(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether the password must contain special characters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_symbols")

    @property
    @pulumi.getter(name="requireUppercaseCharacters")
    def require_uppercase_characters(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether the password must contain uppercase letters. Valid values:
        - true
        - false (default)
        """
        return pulumi.get(self, "require_uppercase_characters")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetResourceTypesResult',
    'AwaitableGetResourceTypesResult',
    'get_resource_types',
    'get_resource_types_output',
]

@pulumi.output_type
class GetResourceTypesResult:
    """
    A collection of values returned by getResourceTypes.
    """
    def __init__(__self__, id=None, ids=None, output_file=None, product=None, types=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if product and not isinstance(product, str):
            raise TypeError("Expected argument 'product' to be a str")
        pulumi.set(__self__, "product", product)
        if types and not isinstance(types, list):
            raise TypeError("Expected argument 'types' to be a list")
        pulumi.set(__self__, "types", types)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of Resource Type IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def product(self) -> builtins.str:
        """
        Product Code.
        """
        return pulumi.get(self, "product")

    @property
    @pulumi.getter
    def types(self) -> Sequence['outputs.GetResourceTypesTypeResult']:
        """
        A list of Resource Type Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "types")


class AwaitableGetResourceTypesResult(GetResourceTypesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetResourceTypesResult(
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            product=self.product,
            types=self.types)


def get_resource_types(ids: Optional[Sequence[builtins.str]] = None,
                       output_file: Optional[builtins.str] = None,
                       product: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetResourceTypesResult:
    """
    This data source provides Cloud Control Resource Type available to the user.[What is Resource Type](https://next.api.aliyun.com/document/cloudcontrol/2022-08-30/GetResourceType)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.cloudcontrol.get_resource_types(product="VPC",
        ids=["VSwitch"])
    ```


    :param Sequence[builtins.str] ids: A list of Resource Type IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str product: Product Code.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['product'] = product
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cloudcontrol/getResourceTypes:getResourceTypes', __args__, opts=opts, typ=GetResourceTypesResult).value

    return AwaitableGetResourceTypesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        product=pulumi.get(__ret__, 'product'),
        types=pulumi.get(__ret__, 'types'))
def get_resource_types_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                              output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              product: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetResourceTypesResult]:
    """
    This data source provides Cloud Control Resource Type available to the user.[What is Resource Type](https://next.api.aliyun.com/document/cloudcontrol/2022-08-30/GetResourceType)

    > **NOTE:** Available since v1.241.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    name = config.get("name")
    if name is None:
        name = "terraform-example"
    default = alicloud.cloudcontrol.get_resource_types(product="VPC",
        ids=["VSwitch"])
    ```


    :param Sequence[builtins.str] ids: A list of Resource Type IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str product: Product Code.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['product'] = product
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:cloudcontrol/getResourceTypes:getResourceTypes', __args__, opts=opts, typ=GetResourceTypesResult)
    return __ret__.apply(lambda __response__: GetResourceTypesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        product=pulumi.get(__response__, 'product'),
        types=pulumi.get(__response__, 'types')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FileSystemArgs', 'FileSystem']

@pulumi.input_type
class FileSystemArgs:
    def __init__(__self__, *,
                 protocol_type: pulumi.Input[builtins.str],
                 storage_type: pulumi.Input[builtins.str],
                 capacity: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 encrypt_type: Optional[pulumi.Input[builtins.int]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 keytab: Optional[pulumi.Input[builtins.str]] = None,
                 keytab_md5: Optional[pulumi.Input[builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 nfs_acl: Optional[pulumi.Input['FileSystemNfsAclArgs']] = None,
                 options: Optional[pulumi.Input['FileSystemOptionsArgs']] = None,
                 recycle_bin: Optional[pulumi.Input['FileSystemRecycleBinArgs']] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 smb_acl: Optional[pulumi.Input['FileSystemSmbAclArgs']] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a FileSystem resource.
        :param pulumi.Input[builtins.str] protocol_type: File transfer protocol type.
               - When FileSystemType = standard, the values are NFS and SMB.
               - When FileSystemType = extreme, the value is NFS.
               - When FileSystemType = cpfs, the value is cpfs.
        :param pulumi.Input[builtins.str] storage_type: The storage type.
               - When FileSystemType = standard, the values are Performance, Capacity, and Premium.
               - When FileSystemType = extreme, the value is standard or advance.
               - When FileSystemType = cpfs, the values are advance_100(100MB/s/TiB baseline) and advance_200(200MB/s/TiB baseline).
        :param pulumi.Input[builtins.int] capacity: File system capacity.
               
               Unit: GiB, required and valid when FileSystemType = extreme or cpfs.
               
               For optional values, please refer to the actual specifications on the purchase page:
               -[Fast NAS Pay-As-You-Go Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme_post#/buy)
               -[Fast NAS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme#/buy)
               -[Parallel File System CPFS Pay-As-You-Go Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_cpfs_post#/buy)
               -[Parallel File System CPFS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=cpfs#/buy)
        :param pulumi.Input[builtins.str] description: File system description.
               
               Restrictions:
               - 2~128 English or Chinese characters in length.
               - Must start with upper and lower case letters or Chinese, and cannot start with'http: // 'and'https.
               - Can contain numbers, colons (:), underscores (_), or dashes (-).
        :param pulumi.Input[builtins.int] encrypt_type: Whether the file system is encrypted.
               
               Use the KMS service hosting key to encrypt and store the file system disk data. When reading and writing encrypted data, there is no need to decrypt it.
               
               Value:
               - 0 (default): not encrypted.
               - 1:NAS managed key. NAS managed keys are supported when FileSystemType = standard or extreme.
               - 2: User management key. You can manage keys only when FileSystemType = extreme.
        :param pulumi.Input[builtins.str] file_system_type: File system type.
               
               Value:
               - standard (default): Universal NAS
               - extreme: extreme NAS
               - cpfs: file storage CPFS
        :param pulumi.Input[builtins.str] keytab: String of keytab file content encrypted by base64
        :param pulumi.Input[builtins.str] keytab_md5: String of the keytab file content encrypted by MD5
        :param pulumi.Input[builtins.str] kms_key_id: The ID of the KMS key.
               This parameter is required only when EncryptType = 2.
        :param pulumi.Input['FileSystemNfsAclArgs'] nfs_acl: NFS ACL See `nfs_acl` below.
        :param pulumi.Input['FileSystemOptionsArgs'] options: Option. See `options` below.
        :param pulumi.Input['FileSystemRecycleBinArgs'] recycle_bin: Recycle Bin See `recycle_bin` below.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input['FileSystemSmbAclArgs'] smb_acl: SMB ACL See `smb_acl` below.
        :param pulumi.Input[builtins.str] snapshot_id: Only extreme NAS is supported.
               
               > **NOTE:** A file system is created from a snapshot. The version of the created file system is the same as that of the snapshot source file system. For example, if the source file system version of the snapshot is 1 and you need to create A file system of version 2, you can first create A file system A from the snapshot, then create A file system B that meets the configuration of version 2, copy the data in file system A to file system B, and migrate the business to file system B after the copy is completed.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Label information collection.
        :param pulumi.Input[builtins.str] vpc_id: The ID of the VPC network.
               This parameter must be configured when FileSystemType = cpfs.
               When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        :param pulumi.Input[builtins.str] vswitch_id: The ID of the switch.
               This parameter must be configured when FileSystemType = cpfs.
               When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        :param pulumi.Input[builtins.str] zone_id: The zone ID.
               
               The usable area refers to the physical area where power and network are independent of each other in the same area.
               
               When the FileSystemType is set to standard, this parameter is optional. By default, a zone that meets the conditions is randomly selected based on the ProtocolType and StorageType configurations. This parameter is required when FileSystemType = extreme or FileSystemType = cpfs.
               
               > **NOTE:** - file systems in different zones in the same region communicate with ECS cloud servers.
               
               > **NOTE:** - We recommend that the file system and the ECS instance belong to the same zone to avoid cross-zone latency.
        """
        pulumi.set(__self__, "protocol_type", protocol_type)
        pulumi.set(__self__, "storage_type", storage_type)
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if encrypt_type is not None:
            pulumi.set(__self__, "encrypt_type", encrypt_type)
        if file_system_type is not None:
            pulumi.set(__self__, "file_system_type", file_system_type)
        if keytab is not None:
            pulumi.set(__self__, "keytab", keytab)
        if keytab_md5 is not None:
            pulumi.set(__self__, "keytab_md5", keytab_md5)
        if kms_key_id is not None:
            pulumi.set(__self__, "kms_key_id", kms_key_id)
        if nfs_acl is not None:
            pulumi.set(__self__, "nfs_acl", nfs_acl)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if recycle_bin is not None:
            pulumi.set(__self__, "recycle_bin", recycle_bin)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if smb_acl is not None:
            pulumi.set(__self__, "smb_acl", smb_acl)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> pulumi.Input[builtins.str]:
        """
        File transfer protocol type.
        - When FileSystemType = standard, the values are NFS and SMB.
        - When FileSystemType = extreme, the value is NFS.
        - When FileSystemType = cpfs, the value is cpfs.
        """
        return pulumi.get(self, "protocol_type")

    @protocol_type.setter
    def protocol_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol_type", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Input[builtins.str]:
        """
        The storage type.
        - When FileSystemType = standard, the values are Performance, Capacity, and Premium.
        - When FileSystemType = extreme, the value is standard or advance.
        - When FileSystemType = cpfs, the values are advance_100(100MB/s/TiB baseline) and advance_200(200MB/s/TiB baseline).
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        File system capacity.

        Unit: GiB, required and valid when FileSystemType = extreme or cpfs.

        For optional values, please refer to the actual specifications on the purchase page:
        -[Fast NAS Pay-As-You-Go Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme_post#/buy)
        -[Fast NAS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme#/buy)
        -[Parallel File System CPFS Pay-As-You-Go Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_cpfs_post#/buy)
        -[Parallel File System CPFS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=cpfs#/buy)
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        File system description.

        Restrictions:
        - 2~128 English or Chinese characters in length.
        - Must start with upper and lower case letters or Chinese, and cannot start with'http: // 'and'https.
        - Can contain numbers, colons (:), underscores (_), or dashes (-).
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="encryptType")
    def encrypt_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Whether the file system is encrypted.

        Use the KMS service hosting key to encrypt and store the file system disk data. When reading and writing encrypted data, there is no need to decrypt it.

        Value:
        - 0 (default): not encrypted.
        - 1:NAS managed key. NAS managed keys are supported when FileSystemType = standard or extreme.
        - 2: User management key. You can manage keys only when FileSystemType = extreme.
        """
        return pulumi.get(self, "encrypt_type")

    @encrypt_type.setter
    def encrypt_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "encrypt_type", value)

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        File system type.

        Value:
        - standard (default): Universal NAS
        - extreme: extreme NAS
        - cpfs: file storage CPFS
        """
        return pulumi.get(self, "file_system_type")

    @file_system_type.setter
    def file_system_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_type", value)

    @property
    @pulumi.getter
    def keytab(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        String of keytab file content encrypted by base64
        """
        return pulumi.get(self, "keytab")

    @keytab.setter
    def keytab(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keytab", value)

    @property
    @pulumi.getter(name="keytabMd5")
    def keytab_md5(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        String of the keytab file content encrypted by MD5
        """
        return pulumi.get(self, "keytab_md5")

    @keytab_md5.setter
    def keytab_md5(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keytab_md5", value)

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the KMS key.
        This parameter is required only when EncryptType = 2.
        """
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kms_key_id", value)

    @property
    @pulumi.getter(name="nfsAcl")
    def nfs_acl(self) -> Optional[pulumi.Input['FileSystemNfsAclArgs']]:
        """
        NFS ACL See `nfs_acl` below.
        """
        return pulumi.get(self, "nfs_acl")

    @nfs_acl.setter
    def nfs_acl(self, value: Optional[pulumi.Input['FileSystemNfsAclArgs']]):
        pulumi.set(self, "nfs_acl", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input['FileSystemOptionsArgs']]:
        """
        Option. See `options` below.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input['FileSystemOptionsArgs']]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter(name="recycleBin")
    def recycle_bin(self) -> Optional[pulumi.Input['FileSystemRecycleBinArgs']]:
        """
        Recycle Bin See `recycle_bin` below.
        """
        return pulumi.get(self, "recycle_bin")

    @recycle_bin.setter
    def recycle_bin(self, value: Optional[pulumi.Input['FileSystemRecycleBinArgs']]):
        pulumi.set(self, "recycle_bin", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="smbAcl")
    def smb_acl(self) -> Optional[pulumi.Input['FileSystemSmbAclArgs']]:
        """
        SMB ACL See `smb_acl` below.
        """
        return pulumi.get(self, "smb_acl")

    @smb_acl.setter
    def smb_acl(self, value: Optional[pulumi.Input['FileSystemSmbAclArgs']]):
        pulumi.set(self, "smb_acl", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Only extreme NAS is supported.

        > **NOTE:** A file system is created from a snapshot. The version of the created file system is the same as that of the snapshot source file system. For example, if the source file system version of the snapshot is 1 and you need to create A file system of version 2, you can first create A file system A from the snapshot, then create A file system B that meets the configuration of version 2, copy the data in file system A to file system B, and migrate the business to file system B after the copy is completed.
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Label information collection.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the VPC network.
        This parameter must be configured when FileSystemType = cpfs.
        When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the switch.
        This parameter must be configured when FileSystemType = cpfs.
        When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The zone ID.

        The usable area refers to the physical area where power and network are independent of each other in the same area.

        When the FileSystemType is set to standard, this parameter is optional. By default, a zone that meets the conditions is randomly selected based on the ProtocolType and StorageType configurations. This parameter is required when FileSystemType = extreme or FileSystemType = cpfs.

        > **NOTE:** - file systems in different zones in the same region communicate with ECS cloud servers.

        > **NOTE:** - We recommend that the file system and the ECS instance belong to the same zone to avoid cross-zone latency.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _FileSystemState:
    def __init__(__self__, *,
                 capacity: Optional[pulumi.Input[builtins.int]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 encrypt_type: Optional[pulumi.Input[builtins.int]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 keytab: Optional[pulumi.Input[builtins.str]] = None,
                 keytab_md5: Optional[pulumi.Input[builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 nfs_acl: Optional[pulumi.Input['FileSystemNfsAclArgs']] = None,
                 options: Optional[pulumi.Input['FileSystemOptionsArgs']] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 recycle_bin: Optional[pulumi.Input['FileSystemRecycleBinArgs']] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 smb_acl: Optional[pulumi.Input['FileSystemSmbAclArgs']] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering FileSystem resources.
        :param pulumi.Input[builtins.int] capacity: File system capacity.
               
               Unit: GiB, required and valid when FileSystemType = extreme or cpfs.
               
               For optional values, please refer to the actual specifications on the purchase page:
               -[Fast NAS Pay-As-You-Go Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme_post#/buy)
               -[Fast NAS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme#/buy)
               -[Parallel File System CPFS Pay-As-You-Go Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_cpfs_post#/buy)
               -[Parallel File System CPFS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=cpfs#/buy)
        :param pulumi.Input[builtins.str] create_time: CreateTime
        :param pulumi.Input[builtins.str] description: File system description.
               
               Restrictions:
               - 2~128 English or Chinese characters in length.
               - Must start with upper and lower case letters or Chinese, and cannot start with'http: // 'and'https.
               - Can contain numbers, colons (:), underscores (_), or dashes (-).
        :param pulumi.Input[builtins.int] encrypt_type: Whether the file system is encrypted.
               
               Use the KMS service hosting key to encrypt and store the file system disk data. When reading and writing encrypted data, there is no need to decrypt it.
               
               Value:
               - 0 (default): not encrypted.
               - 1:NAS managed key. NAS managed keys are supported when FileSystemType = standard or extreme.
               - 2: User management key. You can manage keys only when FileSystemType = extreme.
        :param pulumi.Input[builtins.str] file_system_type: File system type.
               
               Value:
               - standard (default): Universal NAS
               - extreme: extreme NAS
               - cpfs: file storage CPFS
        :param pulumi.Input[builtins.str] keytab: String of keytab file content encrypted by base64
        :param pulumi.Input[builtins.str] keytab_md5: String of the keytab file content encrypted by MD5
        :param pulumi.Input[builtins.str] kms_key_id: The ID of the KMS key.
               This parameter is required only when EncryptType = 2.
        :param pulumi.Input['FileSystemNfsAclArgs'] nfs_acl: NFS ACL See `nfs_acl` below.
        :param pulumi.Input['FileSystemOptionsArgs'] options: Option. See `options` below.
        :param pulumi.Input[builtins.str] protocol_type: File transfer protocol type.
               - When FileSystemType = standard, the values are NFS and SMB.
               - When FileSystemType = extreme, the value is NFS.
               - When FileSystemType = cpfs, the value is cpfs.
        :param pulumi.Input['FileSystemRecycleBinArgs'] recycle_bin: Recycle Bin See `recycle_bin` below.
        :param pulumi.Input[builtins.str] region_id: RegionId
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input['FileSystemSmbAclArgs'] smb_acl: SMB ACL See `smb_acl` below.
        :param pulumi.Input[builtins.str] snapshot_id: Only extreme NAS is supported.
               
               > **NOTE:** A file system is created from a snapshot. The version of the created file system is the same as that of the snapshot source file system. For example, if the source file system version of the snapshot is 1 and you need to create A file system of version 2, you can first create A file system A from the snapshot, then create A file system B that meets the configuration of version 2, copy the data in file system A to file system B, and migrate the business to file system B after the copy is completed.
        :param pulumi.Input[builtins.str] status: File system status. Includes:(such as creating a mount point) can only be performed when the file system is in the Running state.
        :param pulumi.Input[builtins.str] storage_type: The storage type.
               - When FileSystemType = standard, the values are Performance, Capacity, and Premium.
               - When FileSystemType = extreme, the value is standard or advance.
               - When FileSystemType = cpfs, the values are advance_100(100MB/s/TiB baseline) and advance_200(200MB/s/TiB baseline).
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Label information collection.
        :param pulumi.Input[builtins.str] vpc_id: The ID of the VPC network.
               This parameter must be configured when FileSystemType = cpfs.
               When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        :param pulumi.Input[builtins.str] vswitch_id: The ID of the switch.
               This parameter must be configured when FileSystemType = cpfs.
               When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        :param pulumi.Input[builtins.str] zone_id: The zone ID.
               
               The usable area refers to the physical area where power and network are independent of each other in the same area.
               
               When the FileSystemType is set to standard, this parameter is optional. By default, a zone that meets the conditions is randomly selected based on the ProtocolType and StorageType configurations. This parameter is required when FileSystemType = extreme or FileSystemType = cpfs.
               
               > **NOTE:** - file systems in different zones in the same region communicate with ECS cloud servers.
               
               > **NOTE:** - We recommend that the file system and the ECS instance belong to the same zone to avoid cross-zone latency.
        """
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if encrypt_type is not None:
            pulumi.set(__self__, "encrypt_type", encrypt_type)
        if file_system_type is not None:
            pulumi.set(__self__, "file_system_type", file_system_type)
        if keytab is not None:
            pulumi.set(__self__, "keytab", keytab)
        if keytab_md5 is not None:
            pulumi.set(__self__, "keytab_md5", keytab_md5)
        if kms_key_id is not None:
            pulumi.set(__self__, "kms_key_id", kms_key_id)
        if nfs_acl is not None:
            pulumi.set(__self__, "nfs_acl", nfs_acl)
        if options is not None:
            pulumi.set(__self__, "options", options)
        if protocol_type is not None:
            pulumi.set(__self__, "protocol_type", protocol_type)
        if recycle_bin is not None:
            pulumi.set(__self__, "recycle_bin", recycle_bin)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if smb_acl is not None:
            pulumi.set(__self__, "smb_acl", smb_acl)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if storage_type is not None:
            pulumi.set(__self__, "storage_type", storage_type)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vswitch_id is not None:
            pulumi.set(__self__, "vswitch_id", vswitch_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        File system capacity.

        Unit: GiB, required and valid when FileSystemType = extreme or cpfs.

        For optional values, please refer to the actual specifications on the purchase page:
        -[Fast NAS Pay-As-You-Go Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme_post#/buy)
        -[Fast NAS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme#/buy)
        -[Parallel File System CPFS Pay-As-You-Go Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_cpfs_post#/buy)
        -[Parallel File System CPFS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=cpfs#/buy)
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        File system description.

        Restrictions:
        - 2~128 English or Chinese characters in length.
        - Must start with upper and lower case letters or Chinese, and cannot start with'http: // 'and'https.
        - Can contain numbers, colons (:), underscores (_), or dashes (-).
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="encryptType")
    def encrypt_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Whether the file system is encrypted.

        Use the KMS service hosting key to encrypt and store the file system disk data. When reading and writing encrypted data, there is no need to decrypt it.

        Value:
        - 0 (default): not encrypted.
        - 1:NAS managed key. NAS managed keys are supported when FileSystemType = standard or extreme.
        - 2: User management key. You can manage keys only when FileSystemType = extreme.
        """
        return pulumi.get(self, "encrypt_type")

    @encrypt_type.setter
    def encrypt_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "encrypt_type", value)

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        File system type.

        Value:
        - standard (default): Universal NAS
        - extreme: extreme NAS
        - cpfs: file storage CPFS
        """
        return pulumi.get(self, "file_system_type")

    @file_system_type.setter
    def file_system_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_type", value)

    @property
    @pulumi.getter
    def keytab(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        String of keytab file content encrypted by base64
        """
        return pulumi.get(self, "keytab")

    @keytab.setter
    def keytab(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keytab", value)

    @property
    @pulumi.getter(name="keytabMd5")
    def keytab_md5(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        String of the keytab file content encrypted by MD5
        """
        return pulumi.get(self, "keytab_md5")

    @keytab_md5.setter
    def keytab_md5(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keytab_md5", value)

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the KMS key.
        This parameter is required only when EncryptType = 2.
        """
        return pulumi.get(self, "kms_key_id")

    @kms_key_id.setter
    def kms_key_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kms_key_id", value)

    @property
    @pulumi.getter(name="nfsAcl")
    def nfs_acl(self) -> Optional[pulumi.Input['FileSystemNfsAclArgs']]:
        """
        NFS ACL See `nfs_acl` below.
        """
        return pulumi.get(self, "nfs_acl")

    @nfs_acl.setter
    def nfs_acl(self, value: Optional[pulumi.Input['FileSystemNfsAclArgs']]):
        pulumi.set(self, "nfs_acl", value)

    @property
    @pulumi.getter
    def options(self) -> Optional[pulumi.Input['FileSystemOptionsArgs']]:
        """
        Option. See `options` below.
        """
        return pulumi.get(self, "options")

    @options.setter
    def options(self, value: Optional[pulumi.Input['FileSystemOptionsArgs']]):
        pulumi.set(self, "options", value)

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        File transfer protocol type.
        - When FileSystemType = standard, the values are NFS and SMB.
        - When FileSystemType = extreme, the value is NFS.
        - When FileSystemType = cpfs, the value is cpfs.
        """
        return pulumi.get(self, "protocol_type")

    @protocol_type.setter
    def protocol_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol_type", value)

    @property
    @pulumi.getter(name="recycleBin")
    def recycle_bin(self) -> Optional[pulumi.Input['FileSystemRecycleBinArgs']]:
        """
        Recycle Bin See `recycle_bin` below.
        """
        return pulumi.get(self, "recycle_bin")

    @recycle_bin.setter
    def recycle_bin(self, value: Optional[pulumi.Input['FileSystemRecycleBinArgs']]):
        pulumi.set(self, "recycle_bin", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        RegionId
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="smbAcl")
    def smb_acl(self) -> Optional[pulumi.Input['FileSystemSmbAclArgs']]:
        """
        SMB ACL See `smb_acl` below.
        """
        return pulumi.get(self, "smb_acl")

    @smb_acl.setter
    def smb_acl(self, value: Optional[pulumi.Input['FileSystemSmbAclArgs']]):
        pulumi.set(self, "smb_acl", value)

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Only extreme NAS is supported.

        > **NOTE:** A file system is created from a snapshot. The version of the created file system is the same as that of the snapshot source file system. For example, if the source file system version of the snapshot is 1 and you need to create A file system of version 2, you can first create A file system A from the snapshot, then create A file system B that meets the configuration of version 2, copy the data in file system A to file system B, and migrate the business to file system B after the copy is completed.
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        File system status. Includes:(such as creating a mount point) can only be performed when the file system is in the Running state.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The storage type.
        - When FileSystemType = standard, the values are Performance, Capacity, and Premium.
        - When FileSystemType = extreme, the value is standard or advance.
        - When FileSystemType = cpfs, the values are advance_100(100MB/s/TiB baseline) and advance_200(200MB/s/TiB baseline).
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Label information collection.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the VPC network.
        This parameter must be configured when FileSystemType = cpfs.
        When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the switch.
        This parameter must be configured when FileSystemType = cpfs.
        When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        """
        return pulumi.get(self, "vswitch_id")

    @vswitch_id.setter
    def vswitch_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vswitch_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The zone ID.

        The usable area refers to the physical area where power and network are independent of each other in the same area.

        When the FileSystemType is set to standard, this parameter is optional. By default, a zone that meets the conditions is randomly selected based on the ProtocolType and StorageType configurations. This parameter is required when FileSystemType = extreme or FileSystemType = cpfs.

        > **NOTE:** - file systems in different zones in the same region communicate with ECS cloud servers.

        > **NOTE:** - We recommend that the file system and the ECS instance belong to the same zone to avoid cross-zone latency.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("alicloud:nas/fileSystem:FileSystem")
class FileSystem(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 encrypt_type: Optional[pulumi.Input[builtins.int]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 keytab: Optional[pulumi.Input[builtins.str]] = None,
                 keytab_md5: Optional[pulumi.Input[builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 nfs_acl: Optional[pulumi.Input[Union['FileSystemNfsAclArgs', 'FileSystemNfsAclArgsDict']]] = None,
                 options: Optional[pulumi.Input[Union['FileSystemOptionsArgs', 'FileSystemOptionsArgsDict']]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 recycle_bin: Optional[pulumi.Input[Union['FileSystemRecycleBinArgs', 'FileSystemRecycleBinArgsDict']]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 smb_acl: Optional[pulumi.Input[Union['FileSystemSmbAclArgs', 'FileSystemSmbAclArgsDict']]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a File Storage (NAS) File System resource.

        File System Instance.

        For information about File Storage (NAS) File System and how to use it, see [What is File System](https://www.alibabacloud.com/help/en/nas/developer-reference/api-nas-2017-06-26-createfilesystem).

        > **NOTE:** Available since v1.33.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.nas.get_zones(file_system_type="standard")
        default_file_system = alicloud.nas.FileSystem("default",
            protocol_type="NFS",
            storage_type="Capacity",
            description=name,
            encrypt_type=1,
            file_system_type="standard",
            recycle_bin={
                "status": "Enable",
                "reserved_days": 10,
            },
            nfs_acl={
                "enabled": True,
            },
            zone_id=default.zones[0].zone_id)
        ```

        ## Import

        File Storage (NAS) File System can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:nas/fileSystem:FileSystem example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] capacity: File system capacity.
               
               Unit: GiB, required and valid when FileSystemType = extreme or cpfs.
               
               For optional values, please refer to the actual specifications on the purchase page:
               -[Fast NAS Pay-As-You-Go Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme_post#/buy)
               -[Fast NAS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme#/buy)
               -[Parallel File System CPFS Pay-As-You-Go Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_cpfs_post#/buy)
               -[Parallel File System CPFS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=cpfs#/buy)
        :param pulumi.Input[builtins.str] description: File system description.
               
               Restrictions:
               - 2~128 English or Chinese characters in length.
               - Must start with upper and lower case letters or Chinese, and cannot start with'http: // 'and'https.
               - Can contain numbers, colons (:), underscores (_), or dashes (-).
        :param pulumi.Input[builtins.int] encrypt_type: Whether the file system is encrypted.
               
               Use the KMS service hosting key to encrypt and store the file system disk data. When reading and writing encrypted data, there is no need to decrypt it.
               
               Value:
               - 0 (default): not encrypted.
               - 1:NAS managed key. NAS managed keys are supported when FileSystemType = standard or extreme.
               - 2: User management key. You can manage keys only when FileSystemType = extreme.
        :param pulumi.Input[builtins.str] file_system_type: File system type.
               
               Value:
               - standard (default): Universal NAS
               - extreme: extreme NAS
               - cpfs: file storage CPFS
        :param pulumi.Input[builtins.str] keytab: String of keytab file content encrypted by base64
        :param pulumi.Input[builtins.str] keytab_md5: String of the keytab file content encrypted by MD5
        :param pulumi.Input[builtins.str] kms_key_id: The ID of the KMS key.
               This parameter is required only when EncryptType = 2.
        :param pulumi.Input[Union['FileSystemNfsAclArgs', 'FileSystemNfsAclArgsDict']] nfs_acl: NFS ACL See `nfs_acl` below.
        :param pulumi.Input[Union['FileSystemOptionsArgs', 'FileSystemOptionsArgsDict']] options: Option. See `options` below.
        :param pulumi.Input[builtins.str] protocol_type: File transfer protocol type.
               - When FileSystemType = standard, the values are NFS and SMB.
               - When FileSystemType = extreme, the value is NFS.
               - When FileSystemType = cpfs, the value is cpfs.
        :param pulumi.Input[Union['FileSystemRecycleBinArgs', 'FileSystemRecycleBinArgsDict']] recycle_bin: Recycle Bin See `recycle_bin` below.
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Union['FileSystemSmbAclArgs', 'FileSystemSmbAclArgsDict']] smb_acl: SMB ACL See `smb_acl` below.
        :param pulumi.Input[builtins.str] snapshot_id: Only extreme NAS is supported.
               
               > **NOTE:** A file system is created from a snapshot. The version of the created file system is the same as that of the snapshot source file system. For example, if the source file system version of the snapshot is 1 and you need to create A file system of version 2, you can first create A file system A from the snapshot, then create A file system B that meets the configuration of version 2, copy the data in file system A to file system B, and migrate the business to file system B after the copy is completed.
        :param pulumi.Input[builtins.str] storage_type: The storage type.
               - When FileSystemType = standard, the values are Performance, Capacity, and Premium.
               - When FileSystemType = extreme, the value is standard or advance.
               - When FileSystemType = cpfs, the values are advance_100(100MB/s/TiB baseline) and advance_200(200MB/s/TiB baseline).
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Label information collection.
        :param pulumi.Input[builtins.str] vpc_id: The ID of the VPC network.
               This parameter must be configured when FileSystemType = cpfs.
               When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        :param pulumi.Input[builtins.str] vswitch_id: The ID of the switch.
               This parameter must be configured when FileSystemType = cpfs.
               When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        :param pulumi.Input[builtins.str] zone_id: The zone ID.
               
               The usable area refers to the physical area where power and network are independent of each other in the same area.
               
               When the FileSystemType is set to standard, this parameter is optional. By default, a zone that meets the conditions is randomly selected based on the ProtocolType and StorageType configurations. This parameter is required when FileSystemType = extreme or FileSystemType = cpfs.
               
               > **NOTE:** - file systems in different zones in the same region communicate with ECS cloud servers.
               
               > **NOTE:** - We recommend that the file system and the ECS instance belong to the same zone to avoid cross-zone latency.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FileSystemArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a File Storage (NAS) File System resource.

        File System Instance.

        For information about File Storage (NAS) File System and how to use it, see [What is File System](https://www.alibabacloud.com/help/en/nas/developer-reference/api-nas-2017-06-26-createfilesystem).

        > **NOTE:** Available since v1.33.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.nas.get_zones(file_system_type="standard")
        default_file_system = alicloud.nas.FileSystem("default",
            protocol_type="NFS",
            storage_type="Capacity",
            description=name,
            encrypt_type=1,
            file_system_type="standard",
            recycle_bin={
                "status": "Enable",
                "reserved_days": 10,
            },
            nfs_acl={
                "enabled": True,
            },
            zone_id=default.zones[0].zone_id)
        ```

        ## Import

        File Storage (NAS) File System can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:nas/fileSystem:FileSystem example <id>
        ```

        :param str resource_name: The name of the resource.
        :param FileSystemArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FileSystemArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 encrypt_type: Optional[pulumi.Input[builtins.int]] = None,
                 file_system_type: Optional[pulumi.Input[builtins.str]] = None,
                 keytab: Optional[pulumi.Input[builtins.str]] = None,
                 keytab_md5: Optional[pulumi.Input[builtins.str]] = None,
                 kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
                 nfs_acl: Optional[pulumi.Input[Union['FileSystemNfsAclArgs', 'FileSystemNfsAclArgsDict']]] = None,
                 options: Optional[pulumi.Input[Union['FileSystemOptionsArgs', 'FileSystemOptionsArgsDict']]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 recycle_bin: Optional[pulumi.Input[Union['FileSystemRecycleBinArgs', 'FileSystemRecycleBinArgsDict']]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 smb_acl: Optional[pulumi.Input[Union['FileSystemSmbAclArgs', 'FileSystemSmbAclArgsDict']]] = None,
                 snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FileSystemArgs.__new__(FileSystemArgs)

            __props__.__dict__["capacity"] = capacity
            __props__.__dict__["description"] = description
            __props__.__dict__["encrypt_type"] = encrypt_type
            __props__.__dict__["file_system_type"] = file_system_type
            __props__.__dict__["keytab"] = keytab
            __props__.__dict__["keytab_md5"] = keytab_md5
            __props__.__dict__["kms_key_id"] = kms_key_id
            __props__.__dict__["nfs_acl"] = nfs_acl
            __props__.__dict__["options"] = options
            if protocol_type is None and not opts.urn:
                raise TypeError("Missing required property 'protocol_type'")
            __props__.__dict__["protocol_type"] = protocol_type
            __props__.__dict__["recycle_bin"] = recycle_bin
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["smb_acl"] = smb_acl
            __props__.__dict__["snapshot_id"] = snapshot_id
            if storage_type is None and not opts.urn:
                raise TypeError("Missing required property 'storage_type'")
            __props__.__dict__["storage_type"] = storage_type
            __props__.__dict__["tags"] = tags
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["vswitch_id"] = vswitch_id
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["region_id"] = None
            __props__.__dict__["status"] = None
        super(FileSystem, __self__).__init__(
            'alicloud:nas/fileSystem:FileSystem',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacity: Optional[pulumi.Input[builtins.int]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            encrypt_type: Optional[pulumi.Input[builtins.int]] = None,
            file_system_type: Optional[pulumi.Input[builtins.str]] = None,
            keytab: Optional[pulumi.Input[builtins.str]] = None,
            keytab_md5: Optional[pulumi.Input[builtins.str]] = None,
            kms_key_id: Optional[pulumi.Input[builtins.str]] = None,
            nfs_acl: Optional[pulumi.Input[Union['FileSystemNfsAclArgs', 'FileSystemNfsAclArgsDict']]] = None,
            options: Optional[pulumi.Input[Union['FileSystemOptionsArgs', 'FileSystemOptionsArgsDict']]] = None,
            protocol_type: Optional[pulumi.Input[builtins.str]] = None,
            recycle_bin: Optional[pulumi.Input[Union['FileSystemRecycleBinArgs', 'FileSystemRecycleBinArgsDict']]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            smb_acl: Optional[pulumi.Input[Union['FileSystemSmbAclArgs', 'FileSystemSmbAclArgsDict']]] = None,
            snapshot_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            storage_type: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vswitch_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'FileSystem':
        """
        Get an existing FileSystem resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] capacity: File system capacity.
               
               Unit: GiB, required and valid when FileSystemType = extreme or cpfs.
               
               For optional values, please refer to the actual specifications on the purchase page:
               -[Fast NAS Pay-As-You-Go Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme_post#/buy)
               -[Fast NAS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme#/buy)
               -[Parallel File System CPFS Pay-As-You-Go Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_cpfs_post#/buy)
               -[Parallel File System CPFS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=cpfs#/buy)
        :param pulumi.Input[builtins.str] create_time: CreateTime
        :param pulumi.Input[builtins.str] description: File system description.
               
               Restrictions:
               - 2~128 English or Chinese characters in length.
               - Must start with upper and lower case letters or Chinese, and cannot start with'http: // 'and'https.
               - Can contain numbers, colons (:), underscores (_), or dashes (-).
        :param pulumi.Input[builtins.int] encrypt_type: Whether the file system is encrypted.
               
               Use the KMS service hosting key to encrypt and store the file system disk data. When reading and writing encrypted data, there is no need to decrypt it.
               
               Value:
               - 0 (default): not encrypted.
               - 1:NAS managed key. NAS managed keys are supported when FileSystemType = standard or extreme.
               - 2: User management key. You can manage keys only when FileSystemType = extreme.
        :param pulumi.Input[builtins.str] file_system_type: File system type.
               
               Value:
               - standard (default): Universal NAS
               - extreme: extreme NAS
               - cpfs: file storage CPFS
        :param pulumi.Input[builtins.str] keytab: String of keytab file content encrypted by base64
        :param pulumi.Input[builtins.str] keytab_md5: String of the keytab file content encrypted by MD5
        :param pulumi.Input[builtins.str] kms_key_id: The ID of the KMS key.
               This parameter is required only when EncryptType = 2.
        :param pulumi.Input[Union['FileSystemNfsAclArgs', 'FileSystemNfsAclArgsDict']] nfs_acl: NFS ACL See `nfs_acl` below.
        :param pulumi.Input[Union['FileSystemOptionsArgs', 'FileSystemOptionsArgsDict']] options: Option. See `options` below.
        :param pulumi.Input[builtins.str] protocol_type: File transfer protocol type.
               - When FileSystemType = standard, the values are NFS and SMB.
               - When FileSystemType = extreme, the value is NFS.
               - When FileSystemType = cpfs, the value is cpfs.
        :param pulumi.Input[Union['FileSystemRecycleBinArgs', 'FileSystemRecycleBinArgsDict']] recycle_bin: Recycle Bin See `recycle_bin` below.
        :param pulumi.Input[builtins.str] region_id: RegionId
        :param pulumi.Input[builtins.str] resource_group_id: The ID of the resource group.
        :param pulumi.Input[Union['FileSystemSmbAclArgs', 'FileSystemSmbAclArgsDict']] smb_acl: SMB ACL See `smb_acl` below.
        :param pulumi.Input[builtins.str] snapshot_id: Only extreme NAS is supported.
               
               > **NOTE:** A file system is created from a snapshot. The version of the created file system is the same as that of the snapshot source file system. For example, if the source file system version of the snapshot is 1 and you need to create A file system of version 2, you can first create A file system A from the snapshot, then create A file system B that meets the configuration of version 2, copy the data in file system A to file system B, and migrate the business to file system B after the copy is completed.
        :param pulumi.Input[builtins.str] status: File system status. Includes:(such as creating a mount point) can only be performed when the file system is in the Running state.
        :param pulumi.Input[builtins.str] storage_type: The storage type.
               - When FileSystemType = standard, the values are Performance, Capacity, and Premium.
               - When FileSystemType = extreme, the value is standard or advance.
               - When FileSystemType = cpfs, the values are advance_100(100MB/s/TiB baseline) and advance_200(200MB/s/TiB baseline).
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Label information collection.
        :param pulumi.Input[builtins.str] vpc_id: The ID of the VPC network.
               This parameter must be configured when FileSystemType = cpfs.
               When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        :param pulumi.Input[builtins.str] vswitch_id: The ID of the switch.
               This parameter must be configured when FileSystemType = cpfs.
               When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        :param pulumi.Input[builtins.str] zone_id: The zone ID.
               
               The usable area refers to the physical area where power and network are independent of each other in the same area.
               
               When the FileSystemType is set to standard, this parameter is optional. By default, a zone that meets the conditions is randomly selected based on the ProtocolType and StorageType configurations. This parameter is required when FileSystemType = extreme or FileSystemType = cpfs.
               
               > **NOTE:** - file systems in different zones in the same region communicate with ECS cloud servers.
               
               > **NOTE:** - We recommend that the file system and the ECS instance belong to the same zone to avoid cross-zone latency.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FileSystemState.__new__(_FileSystemState)

        __props__.__dict__["capacity"] = capacity
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["encrypt_type"] = encrypt_type
        __props__.__dict__["file_system_type"] = file_system_type
        __props__.__dict__["keytab"] = keytab
        __props__.__dict__["keytab_md5"] = keytab_md5
        __props__.__dict__["kms_key_id"] = kms_key_id
        __props__.__dict__["nfs_acl"] = nfs_acl
        __props__.__dict__["options"] = options
        __props__.__dict__["protocol_type"] = protocol_type
        __props__.__dict__["recycle_bin"] = recycle_bin
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["smb_acl"] = smb_acl
        __props__.__dict__["snapshot_id"] = snapshot_id
        __props__.__dict__["status"] = status
        __props__.__dict__["storage_type"] = storage_type
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vswitch_id"] = vswitch_id
        __props__.__dict__["zone_id"] = zone_id
        return FileSystem(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def capacity(self) -> pulumi.Output[builtins.int]:
        """
        File system capacity.

        Unit: GiB, required and valid when FileSystemType = extreme or cpfs.

        For optional values, please refer to the actual specifications on the purchase page:
        -[Fast NAS Pay-As-You-Go Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme_post#/buy)
        -[Fast NAS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_extreme#/buy)
        -[Parallel File System CPFS Pay-As-You-Go Purchase Page](https://common-buy.aliyun.com/? commodityCode=nas_cpfs_post#/buy)
        -[Parallel File System CPFS Package Monthly Purchase Page](https://common-buy.aliyun.com/? commodityCode=cpfs#/buy)
        """
        return pulumi.get(self, "capacity")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        File system description.

        Restrictions:
        - 2~128 English or Chinese characters in length.
        - Must start with upper and lower case letters or Chinese, and cannot start with'http: // 'and'https.
        - Can contain numbers, colons (:), underscores (_), or dashes (-).
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="encryptType")
    def encrypt_type(self) -> pulumi.Output[builtins.int]:
        """
        Whether the file system is encrypted.

        Use the KMS service hosting key to encrypt and store the file system disk data. When reading and writing encrypted data, there is no need to decrypt it.

        Value:
        - 0 (default): not encrypted.
        - 1:NAS managed key. NAS managed keys are supported when FileSystemType = standard or extreme.
        - 2: User management key. You can manage keys only when FileSystemType = extreme.
        """
        return pulumi.get(self, "encrypt_type")

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> pulumi.Output[builtins.str]:
        """
        File system type.

        Value:
        - standard (default): Universal NAS
        - extreme: extreme NAS
        - cpfs: file storage CPFS
        """
        return pulumi.get(self, "file_system_type")

    @property
    @pulumi.getter
    def keytab(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        String of keytab file content encrypted by base64
        """
        return pulumi.get(self, "keytab")

    @property
    @pulumi.getter(name="keytabMd5")
    def keytab_md5(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        String of the keytab file content encrypted by MD5
        """
        return pulumi.get(self, "keytab_md5")

    @property
    @pulumi.getter(name="kmsKeyId")
    def kms_key_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the KMS key.
        This parameter is required only when EncryptType = 2.
        """
        return pulumi.get(self, "kms_key_id")

    @property
    @pulumi.getter(name="nfsAcl")
    def nfs_acl(self) -> pulumi.Output['outputs.FileSystemNfsAcl']:
        """
        NFS ACL See `nfs_acl` below.
        """
        return pulumi.get(self, "nfs_acl")

    @property
    @pulumi.getter
    def options(self) -> pulumi.Output['outputs.FileSystemOptions']:
        """
        Option. See `options` below.
        """
        return pulumi.get(self, "options")

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> pulumi.Output[builtins.str]:
        """
        File transfer protocol type.
        - When FileSystemType = standard, the values are NFS and SMB.
        - When FileSystemType = extreme, the value is NFS.
        - When FileSystemType = cpfs, the value is cpfs.
        """
        return pulumi.get(self, "protocol_type")

    @property
    @pulumi.getter(name="recycleBin")
    def recycle_bin(self) -> pulumi.Output['outputs.FileSystemRecycleBin']:
        """
        Recycle Bin See `recycle_bin` below.
        """
        return pulumi.get(self, "recycle_bin")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        RegionId
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="smbAcl")
    def smb_acl(self) -> pulumi.Output['outputs.FileSystemSmbAcl']:
        """
        SMB ACL See `smb_acl` below.
        """
        return pulumi.get(self, "smb_acl")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Only extreme NAS is supported.

        > **NOTE:** A file system is created from a snapshot. The version of the created file system is the same as that of the snapshot source file system. For example, if the source file system version of the snapshot is 1 and you need to create A file system of version 2, you can first create A file system A from the snapshot, then create A file system B that meets the configuration of version 2, copy the data in file system A to file system B, and migrate the business to file system B after the copy is completed.
        """
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        File system status. Includes:(such as creating a mount point) can only be performed when the file system is in the Running state.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Output[builtins.str]:
        """
        The storage type.
        - When FileSystemType = standard, the values are Performance, Capacity, and Premium.
        - When FileSystemType = extreme, the value is standard or advance.
        - When FileSystemType = cpfs, the values are advance_100(100MB/s/TiB baseline) and advance_200(200MB/s/TiB baseline).
        """
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Label information collection.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the VPC network.
        This parameter must be configured when FileSystemType = cpfs.
        When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the switch.
        This parameter must be configured when FileSystemType = cpfs.
        When the FileSystemType is standard or extreme, this parameter is reserved for the interface and has not taken effect yet. You do not need to configure it.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        The zone ID.

        The usable area refers to the physical area where power and network are independent of each other in the same area.

        When the FileSystemType is set to standard, this parameter is optional. By default, a zone that meets the conditions is randomly selected based on the ProtocolType and StorageType configurations. This parameter is required when FileSystemType = extreme or FileSystemType = cpfs.

        > **NOTE:** - file systems in different zones in the same region communicate with ECS cloud servers.

        > **NOTE:** - We recommend that the file system and the ECS instance belong to the same zone to avoid cross-zone latency.
        """
        return pulumi.get(self, "zone_id")

